@@ -1,13 +1,15 @@
 /*
- * bdf2sfd 1.1.5
- * Copyright (c) 2019-2020, Frederic Cambus
+ * bdf2sfd 1.1.7
+ * Copyright (c) 2019-2021, Frederic Cambus
  * https://github.com/fcambus/bdf2sfd
  *
  * Created:      2019-11-21
- * Last Updated: 2020-10-20
+ * Last Updated: 2021-11-16
  *
- * bdf2sfd is released under the BSD 2-Clause license
- * See LICENSE file for details
+ * bdf2sfd is released under the BSD 2-Clause license.
+ * See LICENSE file for details.
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
 #include <sys/stat.h>
@@ -35,30 +37,15 @@
 #include "parse.h"
 #include "polygon.h"
 
-struct timespec begin, end, elapsed;
-
-char lineBuffer[LINE_LENGTH_MAX];
-
-FILE *bdfFile;
-struct stat bdfFileStat;
-
-const char *errstr;
-
-int8_t getoptFlag;
-
-char *intputFile;
-
-uint64_t glyphes;
-
 static void
-displayUsage()
+usage()
 {
-	printf("bdf2sfd [-hv] [-f name] [-p name] file \n\n"
+	printf("bdf2sfd [-hv] [-f name] [-p name] font.bdf\n\n"
 	    "The options are as follows:\n\n"
-	    "     -f name     Specify font name.\n"
-	    "     -p name     Specify PostScript font name.\n"
-	    "     -h          Display usage.\n"
-	    "     -v          Display version.\n");
+	    "	-f name	Specify font name.\n"
+	    "	-p name	Specify PostScript font name.\n"
+	    "	-h	Display usage.\n"
+	    "	-v	Display version.\n");
 }
 
 static void
@@ -70,20 +57,30 @@ error(const char *str)
 int
 main(int argc, char *argv[])
 {
-	bool readglyph = false;
-	bool name_allocated = false, psname_allocated = false;
-
-	char *value = NULL;
-
-	int key, stride;
+	struct timespec begin, current, elapsed;
+	struct stat bdf_stat;
 
 	float x = 0.0, y = 0.0;
 	float xlength = 64.0, ylength = 64.0; /* Default for 8x16 fonts */
 
+	uint64_t glyphs = 0;
 	uint32_t height = 0, width = 0;
 	uint32_t ascent = 0, descent = 0;
 	uint32_t mask = 0;
 
+	int opt, key, stride;
+
+	const char *errstr = NULL;
+	char *input;
+	char *value = NULL;
+	char *linebuffer = NULL;
+	size_t linesize = 0;
+
+	bool readglyph = false;
+	bool name_allocated = false, psname_allocated = false;
+
+	FILE *bdf;
+
 	struct fontinfo font;
 	memset(&font, 0, sizeof(struct fontinfo));
 
@@ -103,8 +100,8 @@ main(int argc, char *argv[])
 	}
 #endif
 
-	while ((getoptFlag = getopt(argc, argv, "f:p:hv")) != -1) {
-		switch (getoptFlag) {
+	while ((opt = getopt(argc, argv, "f:p:hv")) != -1) {
+		switch (opt) {
 		case 'f':
 			font.name = optarg;
 			break;
@@ -114,7 +111,7 @@ main(int argc, char *argv[])
 			break;
 
 		case 'h':
-			displayUsage();
+			usage();
 			return EXIT_SUCCESS;
 
 		case 'v':
@@ -124,41 +121,38 @@ main(int argc, char *argv[])
 	}
 
 	if (optind < argc) {
-		intputFile = argv[optind];
+		input = argv[optind];
 	} else {
-		displayUsage();
+		usage();
 		return EXIT_SUCCESS;
 	}
 
-	argc -= optind;
-	argv += optind;
-
 	/* Starting timer */
 	clock_gettime(CLOCK_MONOTONIC, &begin);
 
 	/* Open BDF file */
-	if (!strcmp(intputFile, "-")) {
+	if (!strcmp(input, "-")) {
 		/* Read from standard input */
-		bdfFile = stdin;
+		bdf = stdin;
 	} else {
 		/* Attempt to read from file */
-		if (!(bdfFile = fopen(intputFile, "r"))) {
+		if (!(bdf = fopen(input, "r"))) {
 			perror("Can't open BDF file");
 			return EXIT_FAILURE;
 		}
 	}
 
 	/* Get BDF file size */
-	if (fstat(fileno(bdfFile), &bdfFileStat)) {
+	if (fstat(fileno(bdf), &bdf_stat)) {
 		perror("Can't stat BDF file");
 		return EXIT_FAILURE;
 	}
 
-	while (fgets(lineBuffer, LINE_LENGTH_MAX, bdfFile)) {
-		if (!*lineBuffer)
+	while (getline(&linebuffer, &linesize, bdf) != -1) {
+		if (!*linebuffer)
 			continue;
 
-		key = parseLine(lineBuffer);
+		key = parseLine(linebuffer);
 
 		switch(key) {
 		case FAMILY_NAME:
@@ -283,7 +277,7 @@ main(int argc, char *argv[])
 
 			y = font.ascent;
 			readglyph = true;
-			glyphes++;
+			glyphs++;
 
 			continue;
 
@@ -296,7 +290,7 @@ main(int argc, char *argv[])
 		}
 
 		if (readglyph) {
-			uint32_t row = strtoul(lineBuffer, NULL, 16);
+			uint32_t row = strtoul(linebuffer, NULL, 16);
 
 			polygon(row, mask, width, x, y, xlength, ylength);
 			
@@ -308,16 +302,17 @@ main(int argc, char *argv[])
 			"EndSplineFont\n");
 
 	/* Stopping timer */
-	clock_gettime(CLOCK_MONOTONIC, &end);
+	clock_gettime(CLOCK_MONOTONIC, &current);
 
-	timespecsub(&end, &begin, &elapsed);
+	timespecsub(&current, &begin, &elapsed);
 
 	/* Printing results */
-	fprintf(stderr, "Processed %" PRIu64 " glyphes in %f seconds.\n",
-	    glyphes, elapsed.tv_sec + elapsed.tv_nsec / 1E9);
+	fprintf(stderr, "Processed %" PRIu64 " glyphs in %f seconds.\n",
+	    glyphs, elapsed.tv_sec + elapsed.tv_nsec / 1E9);
 
 	/* Clean up */
-	fclose(bdfFile);
+	free(linebuffer);
+	fclose(bdf);
 
 	if (name_allocated)
 		free(font.name);
