@@ -1,24 +1,26 @@
 /*
- * bdf2sfd 1.1.5
- * Copyright (c) 2019-2020, Frederic Cambus
+ * bdf2sfd 1.1.7
+ * Copyright (c) 2019-2021, Frederic Cambus
  * https://github.com/fcambus/bdf2sfd
  *
  * Created:      2019-11-21
- * Last Updated: 2020-02-08
+ * Last Updated: 2021-02-09
  *
- * bdf2sfd is released under the BSD 2-Clause license
- * See LICENSE file for details
+ * bdf2sfd is released under the BSD 2-Clause license.
+ * See LICENSE file for details.
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
 #include <string.h>
 #include "parse.h"
 
 int
-parseLine(char *lineBuffer) {
+parseLine(char *linebuffer) {
 	char *key = NULL;
 
-	if (*lineBuffer) {
-		key = strtok(lineBuffer, " \t\n");
+	if (*linebuffer) {
+		key = strtok(linebuffer, " \t\n");
 
 		if (key) {
 			if (!strcmp(key, "FAMILY_NAME"))
